/*
 * Copyright 2007 Andrew Wills
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.danann.cernunnos.core;

import java.lang.reflect.Field;

import org.danann.cernunnos.EntityConfig;
import org.danann.cernunnos.Formula;
import org.danann.cernunnos.Phrase;
import org.danann.cernunnos.Reagent;
import org.danann.cernunnos.ReagentType;
import org.danann.cernunnos.SimpleFormula;
import org.danann.cernunnos.SimpleReagent;
import org.danann.cernunnos.TaskRequest;
import org.danann.cernunnos.TaskResponse;

@Deprecated
public final class ConstantPhrase implements Phrase {

	// Instance Members.
	private Phrase field;

	/*
	 * Public API.
	 */

	public static final Reagent FIELD = new SimpleReagent("FIELD", "descendant-or-self::text()", ReagentType.PHRASE,
						String.class, "The fully-qualified name (e.g. com.foo.myproject.MyClass.SOME_CONSTANT) "
						+ "of a static variable.");

	public Formula getFormula() {
		Reagent[] reagents = new Reagent[] {FIELD};
		return new SimpleFormula(getClass(), reagents);
	}

	public void init(EntityConfig config) {

		// Instance Members.
		this.field = (Phrase) config.getValue(FIELD);

	}

	public Object evaluate(TaskRequest req, TaskResponse res) {

		String s = (String) field.evaluate(req, res);
		try {
			String clazz = s.substring(0, s.lastIndexOf("."));
			String var = s.substring(s.lastIndexOf(".") + 1);
			Class c = Class.forName(clazz);
			Field f = c.getDeclaredField(var);
			return f.get(null);
		} catch (Throwable t) {
			String msg = "Unable to instantiate the specified field:  " + s;
			throw new RuntimeException(msg, t);
		}

	}

}
